/********************************************************/
/* Do RESERVES REDUCE CRISIS?							*/
/* Here we do the exercise of Gourinchas & Obstfeld 	*/
/* Pr(SS at t+ k = 1) = beta*Reserves at t 				*/
/* 														*/
/* Date: Dec 15, 2015									*/
/* `today' = 20151215									*/
/* Source >> iip_hk_v`today'.dta 						*/
/* 	  >> bop_ss_v`today'.dta							*/
/* 														*/
/* Output >> obstfeld_v`today'.dta						*/
/********************************************************/

set more off
clear all

local today "20151215"

cap log close
log using obstfeld_log_`today', replace text



/////////////////////////////////////////
/////// -Quarterly SS data     - ////////
/////////////////////////////////////////

use bop_ss_v`today'.dta, clear

keep if qtr == 4

save obstfeld_v`today'.dta, replace

/////////////////////////////////////////
/////// -Yearly Reserves data  - ////////
/////////////////////////////////////////

local tokeep = "wbcode adv_emerging netforeignassetsnfa gdp res_gdp res_debtliab"

merge 1:1 ifs_code year using iip_hk_v`today', gen(_merge_obstfeld) keepusing(`tokeep')  keep(match master using)

gen gnfa =  100*netforeignassetsnfa/gdp
label var gnfa "NFA over GDP"


gen gnfa_res =  gnfa - res_gdp
label var gnfa_res "NFA over GDP less Reserves"

save obstfeld_v`today'.dta, replace

//////////////////////////////////////////
////// List of crises in Gourinchas /////
//////   Gourinchas & Obstfeld      ////
/////////////////////////////////////////

gen ccy = 0
label var ccy "Currency crisis"

gen bnk = 0
label var bnk "Banking crisis"

gen dft = 0
label var dft "Default crisis"

gen sst = gss_year
label var sst "Sudden Stop"

replace ccy 	= 1 if wbcode == "ARG" & (year == 1975 | year == 1981 | year == 1987 | year == 2002)
replace bnk 	= 1 if wbcode == "ARG" & (year == 1980 | year == 1989 | year == 1995 | year == 2001)
//replace dft 	= 1 if wbcode == "ARG" & (year == 1982 | year ==  1989 | year == 2001)
replace dft 	= 1 if wbcode == "ARG" & (year == 1982 | year == 2001)

replace ccy 	= 1 if wbcode == "BRA" & (year == 1976 | year == 1983 | year == 1987 | year == 1992 | year == 1999)
replace bnk 	= 1 if wbcode == "BRA" & (year == 1990 | year == 1994)
//replace dft 	= 1 if wbcode == "BRA" & (year == 1983 | year ==  1986 | year == 1990 | year == 2002)
replace dft 	= 1 if wbcode == "BRA" & (year == 1983 | year == 2002)

replace ccy 	= 1 if wbcode == "CHL" & (year == 1975 | year == 1982)
replace bnk 	= 1 if wbcode == "CHL" & (year == 1976 | year == 1981)
replace dft 	= 1 if wbcode == "CHL" & (year == 1974 | year == 1983)

replace ccy 	= 1 if wbcode == "CHN" & (year == 1984 | year == 1994)
replace bnk 	= 1 if wbcode == "CHN" & (year == 1998)
replace dft 	= 1 if wbcode == "CHN" & (year == .)

replace ccy 	= 1 if wbcode == "COL" & (year == 1985 | year == 1997)
replace bnk 	= 1 if wbcode == "COL" & (year == 1982 | year == 1998)
replace dft 	= 1 if wbcode == "COL" & (year == .)

replace ccy 	= 1 if wbcode == "CZE" & (year == .)
replace bnk 	= 1 if wbcode == "CZE" & (year == 1996)
replace dft 	= 1 if wbcode == "CZE" & (year == .)

replace ccy 	= 1 if wbcode == "EGY" & (year == 1979 | year == 1989 | year == 2003)
replace bnk 	= 1 if wbcode == "EGY" & (year == 1980)
replace dft 	= 1 if wbcode == "EGY" & (year == 1984)

replace ccy 	= 1 if wbcode == "HUN" & (year == .)
replace bnk 	= 1 if wbcode == "HUN" & (year == 1991 | year == 2008)
replace dft 	= 1 if wbcode == "HUN" & (year == .)

replace ccy 	= 1 if wbcode == "IND" & (year == 1991)
replace bnk 	= 1 if wbcode == "IND" & (year == 1993)
replace dft 	= 1 if wbcode == "IND" & (year == 1973)

replace ccy 	= 1 if wbcode == "IDN" & (year == 1978 | year == 1983 | year == 1997)
replace bnk 	= 1 if wbcode == "IDN" & (year == 1997)
replace dft 	= 1 if wbcode == "IDN" & (year == 1997 | year == 1998 | year == 2002)

replace ccy 	= 1 if wbcode == "KOR" & (year == 1980 | year == 1997  | year == 2008)
replace bnk 	= 1 if wbcode == "KOR" & (year == 1997)
replace dft 	= 1 if wbcode == "KOR" & (year == .)

replace ccy 	= 1 if wbcode == "MYS" & (year == 1997)
replace bnk 	= 1 if wbcode == "MYS" & (year == 1997)
replace dft 	= 1 if wbcode == "MYS" & (year == .)

replace ccy 	= 1 if wbcode == "MEX" & (year == 1976 | year == 1982 | year == 1994)
replace bnk 	= 1 if wbcode == "MEX" & (year == 1981 | year == 1994)
replace dft 	= 1 if wbcode == "MEX" & (year == 1982)

replace ccy 	= 1 if wbcode == "MAR" & (year == .)
replace bnk 	= 1 if wbcode == "MAR" & (year == 1980)
replace dft 	= 1 if wbcode == "MAR" & (year == 1983 | year ==  1986)

replace ccy 	= 1 if wbcode == "PAK" & (year == 1982 | year == 2008)
replace bnk 	= 1 if wbcode == "PAK" & (year == .)
replace dft 	= 1 if wbcode == "PAK" & (year == 1981 | year ==  1999)

replace ccy 	= 1 if wbcode == "PER" & (year == 1976 | year == 1982 | year == 1987)
replace bnk 	= 1 if wbcode == "PER" & (year == 1983)
//replace dft 	= 1 if wbcode == "PER" & (year == 1976 | year == 1978 | year == 1980 | year == 1984 | year == 1985)
replace dft 	= 1 if wbcode == "PER" & (year == 1976 | year == 1978 | year == 1980 | year == 1985)

replace ccy 	= 1 if wbcode == "PHL" & (year == 1983 | year == 1997)
replace bnk 	= 1 if wbcode == "PHL" & (year == 1983 | year == 1997)
replace dft 	= 1 if wbcode == "PHL" & (year == 1983)

replace ccy 	= 1 if wbcode == "POL" & (year == 1978 | year == 1986 | year == 1992)
replace bnk 	= 1 if wbcode == "POL" & (year == 1992)
replace dft 	= 1 if wbcode == "POL" & (year == 1981)

replace ccy 	= 1 if wbcode == "ROU" & (year == 1990 | year == 1997)
replace bnk 	= 1 if wbcode == "ROU" & (year == 1990)
replace dft 	= 1 if wbcode == "ROU" & (year == 1981 | year ==  1986)

replace ccy 	= 1 if wbcode == "RUS" & (year == 1998)
replace bnk 	= 1 if wbcode == "RUS" & (year == 1998 | year == 2008)
//replace dft 	= 1 if wbcode == "RUS" & (year == 1991 |  year == 1993 | year == 1998)
replace dft 	= 1 if wbcode == "RUS" & (year == 1991 | year == 1998)

replace ccy 	= 1 if wbcode == "ZAF" & (year == 1984 | year == 2001 | year == 2008)
replace bnk 	= 1 if wbcode == "ZAF" & (year == .)
replace dft 	= 1 if wbcode == "ZAF" & (year == 1985 | year ==  1989 | year == 1993)

replace ccy 	= 1 if wbcode == "THA" & (year == 1997)
replace bnk 	= 1 if wbcode == "THA" & (year == 1983 | year == 1997)
replace dft 	= 1 if wbcode == "THA" & (year == .)

replace ccy 	= 1 if wbcode == "TUR" & (year == 1978 | year == 1988 | year == 1994 | year == 1999)
replace bnk 	= 1 if wbcode == "TUR" & (year == 1982 | year == 2000)
replace dft 	= 1 if wbcode == "TUR" & (year == 1978 | year ==  1982 | year == 2001)


/////////////////////////////////////////
/////// Reserves & Prob. Crisis  ////////
/////////////////////////////////////////

xtset ifs_code year

gen post97 = year >= 1997
gen gfc = year >=2008 & year <= 2009
gen late90s = year >= 1997 & year <= 2001


gen goyears 	= year <= 2011 & year >= 1990

local govars "dft bnk ccy"
//local govars "sst"

// local xvars "res_gdp gnfa_res"
local xvars "res_debtliab gnfa"

local ctrls "i.ifs_code"
//local ctrls "i.ifs_code year"
//local ctrls "i.ifs_code gfc late90s"
//local ctrls "i.ifs_code i.year"


foreach govar of local govars {

	// indicators of future SS (1-3 years)
	gen `govar'_within_1yr = F.`govar'
	label var `govar'_within_1yr "`govar' in 1 year" 

	gen `govar'_within_2yr = F.`govar' | F2.`govar'
	label var `govar'_within_2yr "`govar' in 1-2 years" 

	gen `govar'_within_3yr = F.`govar' | F2.`govar' | F3.`govar'
	label var `govar'_within_3yr "`govar' in 1-3 years" 
	
	// prior year
	gen `govar'_prior_0yr = `govar'
	label var `govar'_prior_0yr "`govar' year" 
	
	gen `govar'_prior_1yr = `govar' | L.`govar'
	label var `govar'_prior_1yr "`govar' past 0-1 year" 

	gen `govar'_prior_2yr = `govar' | L.`govar' | L2.`govar'
	label var `govar'_prior_2yr "`govar' past 0-2 years" 

	gen `govar'_prior_3yr = `govar' | L.`govar' | L2.`govar' | L3.`govar'
	label var `govar'_prior_3yr "`govar' past 0-3 years"
	
	// following year
	gen `govar'_after_0yr = `govar'
	label var `govar'_after_0yr "`govar' year" 
	
	gen `govar'_after_1yr = `govar' | F.`govar'
	label var `govar'_after_1yr "`govar' post 0-1 year" 

	gen `govar'_after_2yr = `govar' | F.`govar' | F2.`govar'
	label var `govar'_after_2yr "`govar' post 0-2 years" 

	gen `govar'_after_3yr = `govar' | F.`govar' | F2.`govar' | F3.`govar'
	label var `govar'_after_3yr "`govar' post 0-3 years"	

}

save obstfeld_v`today'.dta, replace


// Gourinchas-Obstfeld
// Run a panel logit with country fixed effects
// After dropping crisis years & 3 years following

foreach govar of local govars {

	display _newline "*******************************************************************************"
	display 		 "                          CRISIS TYPE: `govar'                                 "
	display     	 "*******************************************************************************"
	
	forvalues i=2(1)3 {
		display _newline "------------------------------------------------------------------------------"
		display 		 "                           HORIZON: t+1 to t+`i'                              " 
		display 		 "------------------------------------------------------------------------------"
		
		// i year horizon - emerging economies - dropped 0-3 years after SS episodes
		quietly logit `govar'_within_`i'yr `xvars' `ctrls' if !`govar'_prior_3yr & adv_emerging == 1 & goyears , vce(robust)
		
		codebook ifs_code year if e(sample), compact
		display "number of obs. = " e(N)
		display "pseudo R-quare = " e(r2_p)
		
		margins if e(sample), atmeans
			
		margins if e(sample), dydx(`xvars') atmeans noatlegend
		
		matrix xm = r(at)
		gen spl_`govar'_`i' = e(sample)
		local counter =1
		local attxt = ""
		
		foreach xvar of local xvars {
		
			display _newline "//////////////////////////////////////////////////////////////////////////////"
			display  	     "                              VARIABLE: `xvar'                                " 
			display 		 "//////////////////////////////////////////////////////////////////////////////"		
			
			quietly reg `xvar' `ctrls' if spl_`govar'_`i'
			quietly predict `xvar'_res_`govar'_`i' if spl_`govar'_`i', residuals
			quietly  sum `xvar'_res_`govar'_`i' if spl_`govar'_`i'
			
			matrix xm_`xvar' = xm
			matrix xm_`xvar'[1,`counter'] = xm[1,`counter'] + r(sd)
			local sd = r(sd)			
			local attxt = "`attxt'" + " at((mean)_all `xvar'=" + string(xm_`xvar'[1,`counter'])+")"
			
			// margin for the change in probability by 1sd at the sample mean for each variable
			quietly  logit `govar'_within_`i'yr `xvars' `ctrls' if !`govar'_prior_3yr & adv_emerging == 1 & goyears , vce(robust)
			
			display _newline "       Change in `govar' Probability over 1-`i' year(s) for one S.D. change in `xvar'     "
			margins ,expression(exp(xb())*exp(_b[`xvar']*`sd')/(1+exp(_b[`xvar']*`sd')*exp(xb()))-predict(p)) atmeans noatlegend							
			local counter = `counter'+1
		}
		
		quietly  logit `govar'_within_`i'yr `xvars' `ctrls' if !`govar'_prior_3yr & adv_emerging == 1 & goyears , vce(robust)
		
		// display _newline "Margin `attxt'"
		// margins if e(sample), `attxt' noatlegend
		
		drop spl_`govar'_`i'
		
	}

}



log close





