/////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////

set more off
clear all

local today "20151215"

cap log close
log using jie_extra_log_`today', replace text

use iip_hk_v`today', clear

graph bar (median) res_gdp_avg_era if (split_group == 1 | split_group == 4 ) & (era >= 2 & era<= 6), over(era, label(angle(25) labsize(small)) gap(*.10)) over(split_group)  ytitle("percent of GDP") ylabel(,angle(0)) title("Foreign Reserves over GDP")  legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f) ) name(resgdp_eme_afe, replace)

graph save resgdp_eme_afe.gph, asis replace
graph export resgdp_eme_afe.eps, as(eps) preview(on) replace

graph bar (median) res_debtliab_avg_era if (split_group == 1 | split_group == 4 ) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent of external debt") ylabel(,angle(0)) title("Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(res_debtliab_eme_afe, replace)

graph save res_debtliab_eme_afe.gph, asis replace
graph export res_debtliab_eme_afe.eps, as(eps) preview(on) replace

/////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////

//use bop_ss_v`today'.dta, clear

//bysort ifs_code year: egen gss_yr = total(gss_qtr)
//keep if qtr == 4

//merge 1:1 ifs_code year using iip_hk_v`today', gen(_merge_jiextra) keep(match master using)

use iip_hk_v`today', clear 
save jie_extra_v`today'.dta, replace


bysort ifs_code era: egen end_era = max(year)
bysort ifs_code era: egen start_era = min(year)
gen dur_era = end_era - start_era

xtset
gen log_res_debtliab = log(res_debtliab)
gen d4_res_debtliab = 100* (L0.log_res_debtliab - L4.log_res_debtliab)/4
gen d2_res_debtliab = 100* (L0.log_res_debtliab - L2.log_res_debtliab)/2

bysort ifs_code era: egen _d2res_debtliab_avg_era = mean( d2_res_debtliab ) if year == end_era
bysort ifs_code era: egen _d4res_debtliab_avg_era = mean( d4_res_debtliab ) if year == end_era

gen dres_debtliab_avg_era = .
replace dres_debtliab_avg_era = _d2res_debtliab_avg_era if dur_era ==2
replace dres_debtliab_avg_era = _d4res_debtliab_avg_era if dur_era ==4

xtset
gen d4_res_gdp = 100* (L0.res_gdp/L4.res_gdp)^(1/4) - 100
gen d2_res_gdp = 100* (L0.res_gdp/L2.res_gdp)^(1/4) - 100

bysort ifs_code era: egen _d2res_gdp_avg_era = mean( d2_res_gdp ) if year == end_era
bysort ifs_code era: egen _d4res_gdp_avg_era = mean( d4_res_gdp ) if year == end_era

gen dres_gdp_avg_era = .
replace dres_gdp_avg_era = _d2res_gdp_avg_era if dur_era ==2
replace dres_gdp_avg_era = _d4res_gdp_avg_era if dur_era ==4

graph bar (median) dres_gdp_avg_era if (split_group == 1) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent") ylabel(,angle(0)) title("Growth in Foreign Reserves over GDP") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(dres_gdp_eme, replace)

graph save dres_gdp_eme.gph, asis replace
graph export dres_gdp_eme.eps, as(eps) preview(on) replace

graph bar (median) dres_gdp_avg_era if (split_group == 1| split_group == 3) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent") ylabel(,angle(0)) title("Growth in Foreign Reserves over GDP") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(dres_gdp_eme_baltic, replace)

graph save dres_gdp_eme_baltic.gph, asis replace
graph export dres_gdp_eme_baltic.eps, as(eps) preview(on) replace

graph bar (median) dres_debtliab_avg_era if (split_group == 1) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent") ylabel(,angle(0)) title("Growth in Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(dres_debtliab_eme, replace)

graph save dres_debtliab_eme.gph, asis replace
graph export dres_debtliab_eme.eps, as(eps) preview(on) replace

graph bar (median) dres_debtliab_avg_era if (split_group == 1| split_group == 3) & (era >= 2 & era<= 6), over(era,  label(angle(25) labsize(small))  gap(*.10)) over(split_group)  ytitle("percent") ylabel(,angle(0)) title("Growth in Foreign Reserves over External Debt Liabilities") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.0f)) name(dres_debtliab_eme_baltic, replace)

graph save dres_debtliab_eme_baltic.gph, asis replace
graph export dres_debtliab_eme_baltic.eps, as(eps) preview(on) replace

save jie_extra_v`today'.dta, replace

log close



