/********************************************************/
/* Do RESERVES REDUCE CRISIS?							*/
/* Here we do the exercise of Gourinchas & Obstfeld 	*/
/* Pr(SS at t+ k = 1) = beta*Reserves at t 				*/
/* 														*/
/* Date: Dec 12, 2015									*/
/* `today' = 20151215									*/
/* Source >> SIMULATIONS_1region.dta 					*/
/* 	  	  >> SIMULATIONS_3regions.dta					*/
/* 														*/
/* Output >> go_simul_`src'.dta							*/
/********************************************************/

set more off
clear all

local today "20151215"


/////////////////////////////////////////
/////// -choose which model    - ////////
/////////////////////////////////////////

//local src "SIMULATIONS_1region"
local src "SIMULATIONS_3regions"

cap log close
log using go_`src'_`today', replace text

use `src', clear

save go_simul_`src', replace

/////////////////////////////////////////
/////// Reserves & Prob. Crisis  ////////
/////////////////////////////////////////


egen ccode = group(simul country)

xtset ccode time

replace reserves = 100*reserves

local govars "ss"

foreach govar of local govars {

	// indicators of future SS (1-3 years)
	gen `govar'_within_1yr = F1.`govar' | F2.`govar' | F3.`govar' |F4.`govar' 
	label var `govar'_within_1yr "`govar' in 1 year" 

	gen `govar'_within_2yr = `govar'_within_1yr | F5.`govar' |F6.`govar' |F7.`govar' |F8.`govar'
	label var `govar'_within_2yr "`govar' in 1-2 years" 

	gen `govar'_within_3yr = `govar'_within_2yr | F9.`govar' |F10.`govar' |F11.`govar' |F12.`govar'
	label var `govar'_within_3yr "`govar' in 1-3 years" 
	
	// prior year
	gen `govar'_prior_0yr = `govar'
	label var `govar'_prior_0yr "`govar' year" 
	
	gen `govar'_prior_1yr = `govar'_prior_0yr | L1.`govar' |L2.`govar' |L3.`govar' |L4.`govar'
	label var `govar'_prior_1yr "`govar' past 0-1 year" 

	gen `govar'_prior_2yr = `govar'_prior_1yr | L5.`govar' |L6.`govar' |L7.`govar' |L8.`govar'
	label var `govar'_prior_2yr "`govar' past 0-2 years" 

	gen `govar'_prior_3yr = `govar'_prior_2yr | L9.`govar' |L10.`govar' |L11.`govar' |L12.`govar'
	label var `govar'_prior_3yr "`govar' past 0-3 years"
	
	// following year
	gen `govar'_after_0yr = `govar'
	label var `govar'_after_0yr "`govar' year" 
	
	gen `govar'_after_1yr = `govar'_after_0yr | F1.`govar' |F2.`govar' |F3.`govar' |F4.`govar'
	label var `govar'_after_1yr "`govar' post 0-1 year" 

	gen `govar'_after_2yr = `govar'_after_1yr | F5.`govar' |F6.`govar' |F7.`govar' |F8.`govar'
	label var `govar'_after_2yr "`govar' post 0-2 years" 

	gen `govar'_after_3yr = `govar'_after_2yr | F9.`govar' |F10.`govar' |F11.`govar' |F12.`govar'
	label var `govar'_after_3yr "`govar' post 0-3 years"	

}

gen  yy = int((time-1)/4)
gen  qq = mod((time-1),4) +1

keep if time >= 20 & time <= 70
keep if qq == 4 
keep if simul <= 10

save go_simul_`src', replace


// the Gourinchas-Obstfeld
// Run a panel logit with country fixed effects
// After dropping crisis years & 3 years following

local xvars "reserves"
local ctrls "i.country i.simul"


display _newline "*******************************************************************************"
display 		 "                          CRISIS TYPE: ss                                 "
display     	 "*******************************************************************************"

forvalues i=2(1)3 {
	display _newline "------------------------------------------------------------------------------"
	display 		 "                           HORIZON: t+1 to t+`i'                              " 
	display 		 "------------------------------------------------------------------------------"
	
	// i year horizon - emerging economies - dropped 0-3 years after SS episodes
	quietly logit ss_within_`i'yr reserves `ctrls' if !(ss_prior_3yr), vce(robust)
	
	margins if e(sample), atmeans
		
	margins if e(sample), dydx(reserves) atmeans noatlegend
	
	matrix xm = r(at)
	gen spl_ss_`i' = e(sample)
	local counter =1
	local attxt = ""
	

	display _newline "//////////////////////////////////////////////////////////////////////////////"
	display  	     "                              VARIABLE: reserves                              " 
	display 		 "//////////////////////////////////////////////////////////////////////////////"		
	
	quietly reg reserves `ctrls' if spl_ss_`i'
	quietly predict reserves_res_ss_`i' if spl_ss_`i', residuals
	quietly  sum reserves_res_ss_`i' if spl_ss_`i'
	
	matrix xm_reserves = xm
	matrix xm_reserves[1,`counter'] = xm[1,`counter'] + r(sd)
	local sd = r(sd)			
	local attxt = "`attxt'" + " at((mean)_all reserves=" + string(xm_reserves[1,`counter'])+")"
	
	// margin for the change in probability by 1sd at the sample mean for each variable
	quietly  logit ss_within_`i'yr reserves `ctrls' if !(ss_prior_3yr), vce(robust)
	
	display _newline "       Change in ss Probability over 1-`i' year(s) for one S.D. change in reserves     "
	margins ,expression(exp(xb())*exp(_b[reserves]*`sd')/(1+exp(_b[reserves]*`sd')*exp(xb()))-predict(p)) atmeans noatlegend							
	local counter = `counter'+1
	
	quietly  logit ss_within_`i'yr reserves `ctrls' if !(ss_prior_3yr), vce(robust)
	
	// display _newline "Margin `attxt'"
	// margins if e(sample), `attxt' noatlegend
	
}


log close





