// IMPORT EWN 1970-2011 & CONVERT VARIABLE NAMES

set more off
clear all

local today "20151215"

cap log close
log using ewn_update_log_`today', replace text

import excel using EWN19702011.xlsx, sheet("1970-2011") firstrow case(lower)
drop ad
save ewn2011, replace
describe, fullnames

// RENAME TO VARIABLES TO EWN2007 FORMAT

rename countryname 						country
rename ifsid 							ifs_code
rename year 							year
rename portfolioequityassetsstock 		portfolioequityassets
rename portfolioequityliabilitiessto 	portfolioequityliabilities
rename fdiassetsstock 					fdiassets
rename fdiliabilitiesstock 				fdiliabilities
rename debtassetsstock 					debtassetsportfoliodebtotherinve
rename debtliabilitiesstock 			debtliabilitiesportfoliodebtothe
rename financialderivativesassets 		financialderivativesassets
rename financialderivativesliab 		financialderivativesliabilities
rename fxreservesminusgold 				fxreservesminusgold
rename totalassets 						totalassets 
rename totalliabilities 				totalliabilities
rename nfa 								netforeignassetsnfa
rename officialiip 						netiipasofficiallyreported
rename nfaalternativefdiorequityva 		nfaalternativefdivaluation
rename gdpus  							gdpus
rename nfagdp  							nfagdp
rename currentaccountifsorweo 			currentaccount
rename capitalaccountbalance 			capitalaccount
rename portfoliodebtassets 				portfoliodebtassets
rename portfoliodebtliabilities 		portfoliodebtliabilities
rename otherinvestmentassets 			otherinvestmentassets
rename otherinvestmentliabilities 		otherinvestmentliabilities
rename fdiassetsother 					fdiassetsothervaluation
rename fdiliabilitiesother 				fdiliabilitiesothervaluation
rename exchangerateperiodavg 			exchangeratevisvisusdollarperiod
rename exchangerateendofperiod 			exchangeratevisvisusdollarendofp

// clean up empty entries
drop if country == ""

sort country year

// add data for extrapolation thru 2014 by using growth rates implied from IFS data post 2011.
local tokeep = "country liab_debtsec liab_deriv liab_direct liab_other liab_portfolio liab_total ngdp_usd reserves_tot"

merge 1:1 ifs_code year using country_financial_annual, keepusing(`tokeep') keep(match using matched)

xtset ifs_code year

// compute growth rate for key variables post 2011

gen alt_debtliab 		= liab_other + liab_debtsec

gen gr_alt_debt_liab 	= log(alt_debtliab) - log(L.alt_debtliab)
gen gr_liab_total 		= log(liab_total) - log(L.liab_total)
gen gr_ngdp_usd 		= log(ngdp_usd) - log(L.ngdp_usd)
gen gr_fxres 			= log(reserves_tot) - log(L.reserves_tot)

gen gdpus_hkp 			= gdpus
replace gdpus_hkp		= L.gdpus_hkp*(1 + gr_ngdp_usd)  if year > 2011

gen fxreserves_hkp 		= fxreservesminusgold
replace fxreserves_hkp 	= L.fxreserves_hkp*(1 + gr_fxres) if year > 2011

gen tot_liab_hkp		= totalliabilities
replace tot_liab_hkp	= L.tot_liab_hkp*(1 + gr_liab_total) if year > 2011

gen extdebt_liab_hkp 	= debtliabilitiesportfoliodebtothe
replace extdebt_liab_hkp = L.extdebt_liab_hkp*(1 + gr_alt_debt_liab) if year > 2011

save, replace

log close





