/********************************************************/
/* IFS: Data on BOP & IIP								*/
/* Date: Dec 15, 2015									*/
/* `today' = 20151215									*/
/* Source    											*/
/*	   >> ifs_src_bop	 							 	*/
/* 	  >> ifscode2iso, code_lists,list_emerging 			*/
/* 														*/
/* Output >> bop_ss_v`today'.dta						*/
/********************************************************/

set more off
clear all

local today "20151215"

cap log close
log using bop_ss_log_`today', replace text


///////////////////////////////////////////////////
/////// IFS CA + RGDPGR + NGDP + Debt Liab ////////
///////////////////////////////////////////////////

// add ifs data on quarterly current account
use ifs_src_bop, clear


save bop_ss_v`today'.dta, replace

// retrieve codes
merge m:1 ifs_code using code_lists, keepusing(country wbcode WB_inc ifs_code) gen(_merge_wb) keep(match master)
merge m:1 ifs_code using ifscode2iso, keepusing(iso) gen(_merge_iso) keep(match master)
merge m:1 ifs_code using list_emerging, keepusing(emerging piigs) gen(_merge_id) keep(match master)

// adjust classifications
replace piigs = 0 if piigs == .
replace emerging = 0 if emerging == .
replace emerging = 0 if wbcode == "BWA" // excluding Botswana from emerging countries set

// baltic countries
gen baltic = (wbcode == "EST") | (wbcode == "LVA") | (wbcode == "LTU")

// advanced economies
gen advanced = (wbcode == "FRA") | (wbcode == "USA") | (wbcode == "DEU") | (wbcode == "GBR")

// eastern europe & baltic transition countries not classified elsewhere
gen eutrans = (wbcode == "BGR") | (wbcode == "SVK") | (wbcode == "SVN")

// ignore small island economies & small economies
gen ignore = (wbcode == "ABW") | (wbcode == "ANT") | (wbcode == "ATG") | (wbcode == "BHS") | (wbcode == "BLZ") | (wbcode == "BRN") | (wbcode == "CHE") | (wbcode == "COM") | (wbcode == "CPV") | (wbcode == "DMA") | (wbcode == "EUR") | (wbcode == "FJI") | (wbcode == "GMB") | (wbcode == "GRD") | (wbcode == "JOR") | (wbcode == "KHM") | (wbcode == "KIR") | (wbcode == "KNA") | (wbcode == "LCA") | (wbcode == "LUX") | (wbcode == "LSO") | (wbcode == "MDV") | (wbcode == "MLT") | (wbcode == "MUS") |  (wbcode == "PNG") | (wbcode == "SDN") | (wbcode == "SLB") | (wbcode == "SRB") | (wbcode == "STP") | (wbcode == "SUR") |  (wbcode == "SWZ") | (wbcode == "SYC") | (wbcode == "TTO") | (wbcode == "TON") | (wbcode == "VCT") | (wbcode == "VUT") | (wbcode == "WSM") 

// tag opec countries
gen opec = (wbcode == "OMN") | (wbcode == "QAT") | (wbcode == "ABW") | (wbcode == "LBY") | (wbcode == "NGA") | (wbcode == "VEN") | (wbcode == "IRN") | (wbcode == "KWT") | (wbcode == "SAU") | (wbcode == "ARE") | (wbcode == "DZA")  

// drop opec & small island economies
drop if ignore == 1 | opec == 1

// some labels
label var emerging "is emerging"
label define emerginglbl 0 "non emerging", modify
label define emerginglbl 1 "emerging", modify
label values emerging emerginglbl

label var advanced "is advanced"
label define advancedlbl 0 "non advanced", modify
label define advancedlbl 1 "advanced", modify
label values advanced advancedlbl

label var baltic "is baltic"
label define balticlbl 0 "non baltic", modify
label define balticlbl 1 "baltic", modify
label values baltic balticlbl

label var eutrans "is european transition"
label define eutranslbl 0 "non eu transition", modify
label define eutranslbl 1 "eu transition", modify
label values eutrans eutranslbl

label var piigs "is european transition"
label define piigslbl 0 "non eu transition", modify
label define piigslbl 1 "eu transition", modify
label values piigs piigslbl

gen adv_emerging = .
replace adv_emerging = 1 if emerging == 1
replace adv_emerging = 2 if emerging == 0 & advanced == 1
replace adv_emerging = 3 if emerging == 0 & advanced == 0

label var adv_emerging "advanced/emerging/other - excluding islands & opec"
label define adv_emerginglbl 1 "emerging", modify
label define adv_emerginglbl 2 "advanced", modify
label define adv_emerginglbl 3 "nonemerging nonadvanced", modify
label values adv_emerging adv_emerginglbl


gen split_group = .
replace split_group = 1 if emerging == 1
replace split_group = 2 if piigs 	== 1
replace split_group = 3 if baltic 	== 1
replace split_group = 4 if advanced	== 1
replace split_group = 5 if eutrans	== 1

label var split_group "country groups"
label define split_grouplbl 1 "emerging economies", modify
label define split_grouplbl 2 "euro area periphery", modify
label define split_grouplbl 3 "baltic economies", modify
label define split_grouplbl 4 "advanced economies", modify
label define split_grouplbl 5 "eu transition", modify
label values split_group split_grouplbl

/* eras */

gen era = .
replace era = 1 if year <= 1991
replace era = 2 if 1992 <= year & year <= 1996
replace era = 3 if 1997 <= year & year <= 2001
replace era = 4 if 2002 <= year & year <= 2006
replace era = 5 if 2007 <= year & year <= 2011
replace era = 6 if 2012 <= year & year <= 2014 
label var era "Era"
label define eralbl 1 " pre 1991", modify
label define eralbl 2 "1992-1996", modify
label define eralbl 3 "1997-2001", modify
label define eralbl 4 "2002-2006", modify
label define eralbl 5 "2007-2011", modify
label define eralbl 6 "2012-2014", modify
label values era eralbl

gen yrpre = era == 2
label var yrpre "year 1992-1996"

gen yrpost = era == 4
label var yrpre "year 2002-2006"

/////////////////////////////////////////
/////// -Hur and Kondo measures -////////
/////////////////////////////////////////

// quick clean up
drop if ifs_code == .
drop if cab == . 

// enough observations?
bysort ifs_code: egen _n_data = count(yrqtr)
label var _n_data "number of quarterly obs by country"

bysort ifs_code: egen _min_yrqtr = min(yrqtr)
format _min_yrqtr %tq
label var _min_yrqtr "earliest year in the data"

bysort ifs_code: egen _max_yrqtr = max(yrqtr)
format _max_yrqtr %tq
label var _max_yrqtr "last year in the data"

// parameters for moving avg - long window
local bkwd = 16
local ctrd = 0
local frwd = 0
local totw = `bkwd' + `ctrd' + `frwd'

// parameters for moving avg - short window
local bkwd_short = 3 // put back to 3
local ctrd_short = 1
local frwd_short = 0
local totw_short = `bkwd_short' + `ctrd_short' + `frwd_short'

// cutoff parameters
local cutoff = 2.00
local cutoff_short = 1.60 //1.45
local cutoff_unc = 2.00
local cutoff_low = 1.00

// drop data countries with too few observations
drop if _n_data < 3*`totw'

// reorder
sort ifs_code yrqtr
// ts set
xtset ifs_code yrqtr, quarterly

// create gdp-adjusted numbers
tssmooth ma sgdpusd = gdpusd, window(`bkwd_short' `ctrd_short' `frwd_short')
label var sgdpusd "GDP (ma 4)"

gen gres = 100*reserves/sgdpusd
label var gres "Reserves over GDP"

gen gdres = 100*d.reserves/sgdpusd
label var gdres "Change in Reserves over GDP"

gen gcab = 100*cab/sgdpusd
label var gcab "CAB over GDP"

// reorder
order country yrqtr iso wbcode ifs_code emerging piigs WB_inc cab gcab

save bop_ss_v`today'.dta, replace

/////////////////////////////////////////
/////////////////////////////////////////
//////-New Sudden Stop measures -////////
/////////////////////////////////////////
/////////////////////////////////////////

// ts set
xtset ifs_code yrqtr, quarterly

// smooth series / trend
// moving average over a long window - 16 qtrs
tssmooth ma scab = cab, window(`bkwd' `ctrd' `frwd')
label var scab "C.A. balance (ma)"

tssmooth ma sgcab = gcab, window(`bkwd' `ctrd' `frwd')
label var sgcab "ca/gdp (ma)"

// deviations from trend (from long window moving avg)
gen dcab = cab - scab
label var dcab "ca (dev. from trend)"

gen dgcab = gcab - sgcab
label var dgcab "ca/gdp (dev. from trend)"

// moving average over a short window - 4 qtrs
tssmooth ma scab_short = cab, window(`bkwd_short' `ctrd_short' `frwd_short')
label var scab_short "ca (ma 4)"

tssmooth ma sgcab_short = gcab, window(`bkwd_short' `ctrd_short' `frwd_short')
label var sgcab_short "ca/gdp (ma 4)"

// change over short (4 qtrs) window
gen dcab_short = scab_short - L`totw_short'.scab_short
label var dcab_short "ca chg (ma 4)"

gen rdcab_short = (scab_short - L`totw_short'.scab_short)/abs(scab_short)
label var rdcab_short "rel ca chg (ma 4)"

gen dgcab_short = sgcab_short - L`totw_short'.sgcab_short
label var dgcab_short "ca/gdp chg (ma 4)"

gen rdgcab_short = (sgcab_short - L`totw_short'.sgcab_short)/abs(sgcab_short)
label var rdgcab_short "rel ca/gdp chg (ma 4)"

// moving standard devv- long window
// std dev = [ N/(N-1) ] * (1/N)* sum[(x^i_s - mu^i_t)^2]

gen _sqr_cab = cab^2
tssmooth ma s_sqr_cab = _sqr_cab, window(`bkwd' `ctrd' `frwd')
gen sdev_cab = sqrt( (`totw'/(`totw' - 1))*(s_sqr_cab - scab^2) ) if yrqtr > _min_yrqtr + `bkwd' & yrqtr < _max_yrqtr - `frwd'
label var sdev_cab  " moving s.d. current account balance"

gen _sqr_gcab = gcab^2
tssmooth ma s_sqr_gcab = _sqr_gcab, window(`bkwd' `ctrd' `frwd')
gen sdev_gcab = sqrt( (`totw'/(`totw' - 1))*(s_sqr_gcab - sgcab^2) ) if yrqtr > _min_yrqtr + `bkwd' & yrqtr < _max_yrqtr - `frwd'
label var sdev_gcab  " moving s.d. ca/gdp (value - ma)"

// sudden stop criteria using moving sd
gen lrg_cab = dcab > `cutoff'*sdev_cab if dcab != .
label var lrg_cab "large change in current account balance"

gen lrg_gcab = dgcab > `cutoff'*sdev_gcab if dgcab != .
label var lrg_gcab "large change in ca/gdp"

// sudden stop definition using short window & sd

gen div_cab_short = dcab_short/sdev_cab if dcab_short != .
label var div_cab_short "CA chg v. sd"

gen div_gcab_short = dgcab_short/sdev_gcab if dgcab_short != .
label var div_gcab_short "CA/GDP chg v. sd"

gen lrg_cab_short = dcab_short > `cutoff_short'*sdev_cab if dcab_short != .
label var lrg_cab_short "CA change over sd > `cutoff_short'"

gen lrg_gcab_short = dgcab_short > `cutoff_short'*sdev_gcab if dgcab_short != .
label var lrg_gcab_short "CA change over sd > `cutoff_short'"

// long-run sd of moving average
bysort ifs_code: egen dcab_sd = sd(dcab) if yrqtr > _min_yrqtr + `bkwd' & yrqtr < _max_yrqtr - `frwd'
label var dcab_sd "s.d. ca (value - ma)"

bysort ifs_code: egen dgcab_sd = sd(dgcab) if yrqtr > _min_yrqtr + `bkwd' & yrqtr < _max_yrqtr - `frwd'
label var dgcab_sd "s.d. ca/gdp (value - ma)"

gen div_cab_unc = dcab/dcab_sd if dcab != .
label var div_cab_unc "CA chg v. sd"

gen div_gcab_unc = dgcab/dgcab_sd if dgcab != .
label var div_gcab_unc "CA/GDP chg v. sd"

gen lrg_cab_unc = dcab > `cutoff_unc'*dcab_sd if dcab != .
label var lrg_cab_unc "large change in ca - uncond. s.d."

gen lrg_gcab_unc = dgcab > `cutoff_unc'*dgcab_sd if dgcab != .
label var lrg_gcab_unc "large change in ca/gdp - uncond. s.d."

// recession

gen recession = (rgdp_gr < 0) & (L.rgdp_gr < 0) | (rgdp_gr < 0) & (F.rgdp_gr < 0)
label var recession "Recession"

// plots
// graph twoway (tsline dcab if wbcode == "USA" | wbcode == "GBR" | wbcode == "DEU" | wbcode == "FRA"), by(wbcode) name(adv_1, replace) 

// graph twoway (tsline dcab if wbcode == "ARG" | wbcode == "KOR" | wbcode == "BRA" | wbcode == "THA"), by(wbcode) name(eme_1, replace) 

// graph twoway (tsline cab scab if wbcode == "ARG" ), by(wbcode) name(eme_2, replace) 

// graph twoway (tsline cab scab if wbcode == "RUS"  & year > 1985 & year < 2007), by(wbcode) name(eme_3, replace) 

// list
sort wbcode yrqtr

list wbcode country yrqtr if lrg_cab == 1 & (emerging | piigs |  baltic ), sepby(wbcode)


// dating sudden stop episodes - using short window deviations

// spells of ca deviations
tsspell, c(div_cab_short >= `cutoff_low' & div_cab_short < .) end(_mediumend) seq(_mediumseq) spell(_mediumspell)
tsspell, c(_mediumspell == 0) end(_gapend) seq(_gapseq) spell(_gapspell)

tsspell, c(div_gcab_short >= `cutoff_low' & div_gcab_short < .) end(_gmediumend) seq(_gmediumseq) spell(_gmediumspell)
tsspell, c(_gmediumspell == 0) end(_ggapend) seq(_ggapseq) spell(_ggapspell)

// summary stat by spell
bysort ifs_code _mediumspell _gapspell: egen _hashighdev = max(div_cab_short >= `cutoff_short' & div_cab_short < .)
label var _hashighdev "Spell with large CA reversal"

bysort ifs_code _gmediumspell _ggapspell: egen _ghashighdev = max(div_gcab_short >= `cutoff_short' & div_gcab_short < .)
label var _ghashighdev "Spell with large CA/GDP reversal"

// does spell have recession
bysort ifs_code _mediumspell _gapspell: egen _hasrecession = max(recession)
label var _hasrecession "Spell (CA) containing recession"

bysort ifs_code _gmediumspell _ggapspell: egen _ghasrecession = max(recession)
label var _ghasrecession "Spell (CA/GDP) containing recession"

// defining sudden stop as reversal and recession
gen suddenstopera = _hasrecession &  _hashighdev & _mediumspell
label var suddenstopera "Spell with CA reversal & recession"

gen gsuddenstopera = _ghasrecession &  _ghashighdev & _gmediumspell
label var gsuddenstopera "Spell with CA/GDP reversal & recession"

// defining ca reversal
gen reversalera = _hashighdev & _mediumspell
label var reversalera "Spell with CA reversal"

gen greversalera = _ghashighdev & _gmediumspell
label var greversalera "Spell with CA/GDP reversal"

// tagging sudden stop countries
bysort ifs_code : egen _hadss = max(suddenstopera)
label var _hadss  "Country had SS experience (ca)"

bysort ifs_code : egen _ghadss = max(gsuddenstopera)
label var _ghadss  "Country had SS experience (ca/gdp)"

// tagging ca reversal countries
bysort ifs_code : egen _hadrev = max(reversalera)
label var _hadrev  "Country had CA reversal experience"

bysort ifs_code : egen _ghadrev = max(greversalera)
label var _ghadrev  "Country had CA/GDP reversal experience"

// sudden stop era start
bysort ifs_code _mediumspell: egen _mediummin = min(yrqtr) if _mediumspell > 0
format _mediummin %tq
label var _mediummin  "Time CA spell began"

bysort ifs_code _gmediumspell: egen _gmediummin = min(yrqtr) if _gmediumspell > 0
format _gmediummin %tq
label var _gmediummin  "Time CA/GDP spell began"

sort country yrqtr 

gen _mediumstart = (yrqtr == _mediummin)
label var _mediumstart  "Spell CA started"

gen _gmediumstart = (yrqtr == _gmediummin)
label var _gmediumstart  "Spell CA/GDP started"

// tag spells
egen _tagspell = tag(ifs_code _mediumspell) if _mediumspell > 0
label var _tagspell "Tag CA - Spell"

egen _gtagspell = tag(ifs_code _gmediumspell) if _gmediumspell > 0
label var _gtagspell "Tag CA/GDP - Spell"

// years of sudden stops
bysort ifs_code year: egen ss_year = max(suddenstopera)
label var ss_year  "Year in country SS era (ca)"

bysort ifs_code year: egen gss_year = max(gsuddenstopera)
label var gss_year  "Year in country SS era (ca/gdp)"

// years of sudden stop start
bysort ifs_code year: egen ss_year_started = max(_mediumstart & suddenstopera)
label var ss_year_started  "Year of country SS era start (ca)"

bysort ifs_code year: egen gss_year_started = max(_gmediumstart & gsuddenstopera)
label var gss_year_started  "Year of country SS era start (ca/gdp)"

// country tag
egen _tagcountry = tag(ifs_code)

// listing the SS episodes
sort country yrqtr 

disp(" Sudden stops in emerging countries using CA criterion")
list country yrqtr div_cab_short _mediumspell  if suddenstopera & (emerging | piigs | baltic) & (year >= 1989 & year <= 2015), sepby(country _mediumspell)

tab country year  if suddenstopera & (emerging | piigs | baltic) & (year >= 1989 & year <= 2015) & _mediumstart

disp(" Sudden stops in emerging countries using CA/GDP criterion")
list country yrqtr div_gcab_short _gmediumspell  if gsuddenstopera & (emerging) & (year >= 1989 & year <= 2015), sepby(country _gmediumspell)

tab country year  if gsuddenstopera & (emerging | piigs | baltic) & (year >= 1989 & year <= 2015) & _gmediumstart

// plot
gen upper = `cutoff_short'
label var upper "`cutoff_short'*s.d."
gen lower = `cutoff_low'
label var lower "`cutoff_low'*s.d."

egen __ldiv = min(div_cab_short) if _hadss & (emerging | piigs | baltic) & year >= 1990 & year <= 2015
egen _ldiv = min(__ldiv)

egen __udiv = max(div_cab_short) if _hadss & (emerging | piigs | baltic) & year >= 1990 & year <= 2015
egen _udiv = max(__udiv)

gen plotrec = _udiv if recession == 1
replace plotrec = _ldiv if recession == 0
label var plot "recession"

// graph twoway (tsline div_cab_short upper lower if (wbcode == "KOR" | wbcode == "MEX" | wbcode == "ARG" | wbcode == "BRA" | wbcode == "TUR" | wbcode == "THA") & year >= 1990 & year <= 2007 ), by( wbcode) tlabel(1990q1(8)2007q4, angle(60) labsize(vsmall) grid) ttitle("") name(eme_4, replace) 

graph twoway (tsline div_cab_short div_gcab_short plotrec upper lower if (emerging | piigs | baltic) & year >= 1990 & year <= 2014), by(wbcode) tlabel(1990q1(8)2014q4, angle(60) labsize(vsmall) grid) ttitle("") name(eme_5, replace) 

// summary suddden stop frequencies

disp("sudden stop frequencies")
tabstat gsuddenstopera if emerging , by(era) stat(mean N) format(%9.2f)


disp("sudden stop frequencies")
tabstat gsuddenstopera if baltic | emerging , by(era) stat(mean N) format(%9.2f)

// plots - sudden stop frequencies

gen gss_qtr = _gmediumstart*gsuddenstopera

graph bar (sum)  gss_qtr  if adv_emerging == 1 & (era >= 2 & era <= 5), over(era, gap(*.10) label(angle(0))) ytitle("number of sudden stop episodes") title("Sudden Stops in Emerging Economies") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.2g)) name(eme_6, replace) 

graph save ss_episodes_plot.gph, asis replace
graph export ss_episodes_plot.eps, as(eps) preview(on) replace

graph bar (sum)  gss_qtr  if adv_emerging == 1 & (era >= 2 & era <= 6), over(era, gap(*.10) label(angle(0))) ytitle("number of sudden stop episodes") title("Sudden Stops in Emerging Economies") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.2g)) name(eme_6_bis, replace) 

graph save ss_episodes_bis_plot.gph, asis replace
graph export ss_episodes_bis_plot.eps, as(eps) preview(on) replace

// plots - sudden stop frequencies

graph bar (sum)  gss_qtr  if baltic == 1 & (era >= 2 & era <= 6), over(era, gap(*.10) label(angle(0))) ytitle("number of sudden stop episodes") title("Sudden Stops in Baltic Economies") legend(off) graphregion(fcolor(white)) blabel(bar, position(outside) format(%9.2g)) name(eme_6a, replace) 

graph save ss_episodes_plot_baltic.gph, asis replace
graph export ss_episodes_plot_baltic.eps, as(eps) preview(on) replace

/////////////////////////////////////////
/////////////////////////////////////////
//////-  global imbalance link  -///////
/////////////////////////////////////////
/////////////////////////////////////////

// ts set
xtset ifs_code yrqtr, quarterly

tssmooth ma sreserves_short = reserves, window(`bkwd_short' `ctrd_short' `frwd_short')
label var sreserves "Reserves (ma 4)"

gen snfa_short = nfa if qtr == 4
replace snfa_short = (1*L3.nfa + 3*nfa)/4 if qtr == 3
replace snfa_short = (2*L2.nfa + 2*nfa)/4 if qtr == 2
replace snfa_short = (3*L.nfa + 1*nfa)/4 if qtr == 1
label var snfa_short "NFA (ma 4)"

bysort yrqtr: egen _scab_eme = total(scab_short) if emerging == 1
bysort yrqtr: egen scab_eme = max(_scab_eme)
label var scab_eme "CA balance of EMEs in mil USD"
drop _scab_eme

bysort yrqtr: egen _scab_adv = total(scab_short) if advanced == 1
bysort yrqtr: egen scab_adv = max(_scab_adv) 
label var scab_adv "CA balance of AEs in mil USD"
drop _scab_adv

bysort yrqtr: egen _snfa_adv = total(snfa_short) if advanced == 1
bysort yrqtr: egen snfa_adv = max(_snfa_adv)
label var snfa_adv "NFA of AEs in mil USD"
drop _snfa_adv

// ts set
xtset ifs_code yrqtr, quarterly

bysort yrqtr: egen _sgdp_all = total(sgdpusd) if advanced == 1
bysort yrqtr: egen sgdp_all = max(_sgdp_all)
label var sgdp_all "GDP of ADV in mil USD"
drop _sgdp_all

xtset ifs_code yrqtr, quarterly
gen sreschg_short = sreserves_short - L.sreserves_short
label var sreschg_short "Change in Reserves QoQ in mil USD"

bysort yrqtr: egen _sreschg_eme = total(sreschg_short) if emerging == 1
bysort yrqtr: egen sreschg_eme = max(_sreschg_eme)
label var sreschg_eme "Net Reserves change of EMEs in mil USD"
drop _sreschg_eme

bysort yrqtr: egen _sres_eme = total(sreserves_short) if emerging == 1
bysort yrqtr: egen sres_eme = max(_sres_eme)
label var sres_eme "Reserves of EMEs in mil USD"
drop _sres_eme

// annualizing the flows  and convert in  Bil.
replace sreschg_eme = 4*sreschg_eme/1e3
label var sreschg_eme "Net Reserves yoy change of EMEs in bil USD"

replace sreschg_short = 4*sreschg_short/1e3
label var sreschg_short "Change in Reserves yoy in bil USD"

replace scab_eme = 4*scab_eme/1e3
label var scab_eme "CA balance yoy of EMEs in bil USD"

replace scab_adv = 4*scab_adv/1e3
label var scab_adv "CA balance yoy of AEs in bil USD"

//  convert gdp in bil
replace sgdp_all = sgdp_all/1e3
label var sgdp_all "GDP of ADV in bil USD"

replace sres_eme = sres_eme/1e3
label var sres_eme "Reserves of EMEs in bil USD"

replace snfa_adv = snfa_adv/1e3
label var snfa_adv "Net Foreign Assets of AEs in bil USD"

// measures
gen gsres_short = 100*sreserves_short/sgdp_all
label var gsres_short "Reserves over ADV GDP"

gen gsreschg_short = 100*sreschg_short/sgdp_all
label var gsreschg_short "Reserves flow over ADV GDP"

gen gsres_eme = 100*sres_eme/sgdp_all
label var gsres_eme "EME reserves over ADV GDP"

gen gsreschg_eme = 100*sreschg_eme/sgdp_all
label var gsreschg_eme "EME reserves flow over ADV GDP"

gen gscab_eme = 100*scab_eme/sgdp_all
label var gscab_eme "EME CA flow over ADV GDP"

gen gscab_adv = 100*scab_adv/sgdp_all
label var gscab_adv "ADV CA balance over ADV GDP"

gen gsnfa_adv = 100*snfa_adv/sgdp_all
label var gsnfa_adv "ADV NFA over ADV GDP"


// ts set
xtset ifs_code yrqtr, quarterly

graph twoway (tsline gscab_adv gsreschg_eme if wbcode == "USA" & year >= 1990 & year <= 2014), tlabel(1990q1(8)2014q4, angle(0) labsize(small) grid) tmtick(1990q1(4)2014q4) ttitle("") ytitle("pct of AEs GDP") ylabel( -4(1)4 , angle(0) labsize(small) grid gmax) ymtick(-4(.5)4)  title("Reserves and Global Imbalances") legend(off) ttext(-2.0 2000q1 "AEs Net Current Account", placement(east))  ttext(2.0 2007q1 "EMEs Change in Reserves", placement(west)) graphregion(fcolor(white))  name(eme_7, replace)

graph save imbalance_gdp_plot.gph, asis replace
graph export imbalance_gdp_plot.eps, as(eps) preview(on) replace


graph twoway (tsline scab_adv sreschg_eme if wbcode == "USA" & year >= 1990 & year <= 2014 ), tlabel(1990q1(8)2014q4, angle(0) labsize(small) grid) tmtick(1990q1(4)2014q4) ttitle("") ytitle("mil. USD") ylabel( -800(200)800, angle(0) labsize(small) format(%12.0fc) grid gmax) ymtick(-800(100)800) title("Reserves and Global Imbalances") legend(off)  ttext(-200 2005q4 "AEs Net Current Account", placement(west))  ttext(400 2007q1 "EMEs Change in Reserves", placement(west)) graphregion(fcolor(white))  name(eme_8, replace)

graph save imbalance_usd_plot.gph, asis replace
graph export imbalance_usd_plot.eps, as(eps) preview(on) replace


// plots - total debt liabilities by group
graph twoway (tsline gsnfa_adv gsres_eme if wbcode == "USA" & year >= 1990 & year <= 2014), tlabel(1990q1(8)2014q4, angle(0) labsize(small) grid) tmtick(1990q1(4)2014q4) ttitle("") ytitle("pct of AEs GDP") ylabel( , angle(0) labsize(small) grid gmax) title("Reserves and Global Imbalances") legend(off) ttext(-0.0 2000q1 "AEs Net Foreign Assets", placement(east))  ttext(4.0 2003q1 "EMEs Reserves", placement(west)) graphregion(fcolor(white))  name(eme_9, replace)

save bop_ss_v`today'.dta, replace
log close







